Dask Kubernetes
===============


.. image:: https://github.com/dask/dask-kubernetes/workflows/CI/badge.svg
   :target: https://github.com/dask/dask-kubernetes/actions?query=workflow%3ACI

.. image:: https://img.shields.io/readthedocs/dask-kubernetes?color=%232980B9&logo=read-the-docs&logoColor=white
   :target: https://kubernetes.dask.org/
   :alt: Read the Docs

.. image:: https://img.shields.io/readthedocs/dask-kubernetes?color=%232980B9&label=developer%20docs&logo=read-the-docs&logoColor=white
   :target: https://kubernetes.dask.org/releasing.html
   :alt: Read the Docs Developer

.. image:: https://img.shields.io/pypi/v/dask-kubernetes
   :target: https://pypi.org/project/dask-kubernetes/
   :alt: PyPI

.. image:: https://img.shields.io/conda/vn/conda-forge/dask-kubernetes
   :target: https://anaconda.org/conda-forge/dask-kubernetes
   :alt: Conda Forge


Native Kubernetes integration for Dask.